@@ -1,9 +1,10 @@
+use std::convert::TryFrom;
 use std::ffi::OsString;
 
 use crate::error::{Error, Result};
 
 // TODO: --no-exec? might be required; users sometimes want to execute the file itself.
-pub(crate) const HELP: &str = "thwack
+pub const HELP: &str = "thwack
 Find a file and open it with an arbitrary command.
 
 USAGE:
@@ -17,6 +18,9 @@ OPTIONS:
                               This is run when you hit the Enter on a path
                               The default command is \"notepad\" on Windows, or \"cat\" on other platforms.
     --starting-point <PATH>   Change the starting point from the default (\".\")
+    --status-line <TYPE>      Change the information on the status line.
+                              The possible values are \"absolute\", \"relative\", and \"none.\"
+                              The default is \"absolute.\"
     -h, --help                Prints help information
     -v, --version             Prints version info and exit
 ";
@@ -49,16 +53,22 @@ impl<A: Iterator<Item = OsString>> Parser<A> {
                 "--help" => self.set_help(true),
                 "-v" => self.set_version(true),
                 "--version" => self.set_version(true),
-                "--starting-point" => self.set_starting_point(None)?,
                 "--exec" => self.set_exec(None)?,
+                "--starting-point" => self.set_starting_point(None)?,
+                "--status-line" => self.set_status_line(None)?,
+                x if x.starts_with("--exec=") => {
+                    if let Some((_, val)) = x.split_once('=') {
+                        self.set_exec(Some(val))?;
+                    }
+                }
                 x if x.starts_with("--starting-point=") => {
                     if let Some((_, val)) = x.split_once('=') {
                         self.set_starting_point(Some(val))?;
                     }
                 }
-                x if x.starts_with("--exec=") => {
+                x if x.starts_with("--status-line=") => {
                     if let Some((_, val)) = x.split_once('=') {
-                        self.set_exec(Some(val))?;
+                        self.set_status_line(Some(val))?;
                     }
                 }
                 x => {
@@ -112,6 +122,12 @@ impl<A: Iterator<Item = OsString>> Parser<A> {
         Ok(())
     }
 
+    fn set_status_line(&mut self, value: Option<&str>) -> Result<()> {
+        let value = self.arg_value("--status-line", value)?;
+        self.parsed_args.status_line = StatusLine::try_from(value).map_err(|(_, given)| Error::args(&format!("The argument of \"--status-line\" must be one of \"absolute\", \"relative\", or \"none\": {:?} was given.", given)))?;
+        Ok(())
+    }
+
     fn set_exec(&mut self, value: Option<&str>) -> Result<()> {
         self.parsed_args.exec = self.arg_value("--exec", value)?;
         Ok(())
@@ -145,11 +161,35 @@ impl<A: Iterator<Item = OsString>> Parser<A> {
     }
 }
 
+#[derive(Debug, PartialEq)]
+pub(crate) enum StatusLine {
+    Absolute,
+    Relative,
+    None,
+}
+
+impl TryFrom<String> for StatusLine {
+    type Error = (String, String);
+
+    fn try_from(value: String) -> std::result::Result<Self, Self::Error> {
+        match value.as_ref() {
+            "absolute" => Ok(StatusLine::Absolute),
+            "relative" => Ok(StatusLine::Relative),
+            "none" => Ok(StatusLine::None),
+            _ => Err((
+                "The possible value is one of \"absolute\", \"relative\", or \"none\"".to_string(),
+                value,
+            )),
+        }
+    }
+}
+
 #[derive(Debug, PartialEq)]
 pub(crate) struct ParsedArgs {
     pub(crate) help: bool,
     pub(crate) version: bool,
     pub(crate) starting_point: String,
+    pub(crate) status_line: StatusLine,
     pub(crate) query: String,
     pub(crate) exec: String,
 }
@@ -160,6 +200,7 @@ impl Default for ParsedArgs {
             help: false,
             version: false,
             starting_point: String::from("."),
+            status_line: StatusLine::Absolute,
             query: String::from(""),
             exec: if cfg!(windows) {
                 String::from("notepad")
@@ -349,6 +390,95 @@ mod tests {
         );
     }
 
+    #[test]
+    fn parser_with_status_line() {
+        assert_eq!(
+            Parser::new(args!["program", "--status-line=none"])
+                .parse()
+                .unwrap(),
+            ParsedArgs {
+                status_line: StatusLine::None,
+                ..default!()
+            }
+        );
+        assert_eq!(
+            Parser::new(args!["program", "--status-line=relative"])
+                .parse()
+                .unwrap(),
+            ParsedArgs {
+                status_line: StatusLine::Relative,
+                ..default!()
+            }
+        );
+        assert_eq!(
+            Parser::new(args!["program", "--status-line=absolute"])
+                .parse()
+                .unwrap(),
+            ParsedArgs {
+                status_line: StatusLine::Absolute,
+                ..default!()
+            }
+        );
+        assert_eq!(
+            Parser::new(args!["program", "--status-line", "none"])
+                .parse()
+                .unwrap(),
+            ParsedArgs {
+                status_line: StatusLine::None,
+                ..default!()
+            }
+        );
+        assert_eq!(
+            Parser::new(args!["program", "--status-line", "relative"])
+                .parse()
+                .unwrap(),
+            ParsedArgs {
+                status_line: StatusLine::Relative,
+                ..default!()
+            }
+        );
+        assert_eq!(
+            Parser::new(args!["program", "--status-line", "absolute"])
+                .parse()
+                .unwrap(),
+            ParsedArgs {
+                status_line: StatusLine::Absolute,
+                ..default!()
+            }
+        );
+        assert_eq!(
+            Parser::new(args!["program", "--status-line=unknown"])
+                .parse()
+                .unwrap_err()
+                .message,
+            format!("The argument of \"--status-line\" must be one of \"absolute\", \"relative\", or \"none\": \"unknown\" was given."),
+        );
+        assert_eq!(
+            Parser::new(args!["program", "--status-line"])
+                .parse()
+                .unwrap_err()
+                .message,
+            format!("{}\n\n\"--status-line\" needs a value.", HELP),
+        );
+        assert_eq!(
+            Parser::new(args!["program", "--status-line", "--"])
+                .parse()
+                .unwrap_err()
+                .message,
+            format!("{}\n\n\"--status-line\" needs a value.", HELP),
+        );
+        assert_eq!(
+            Parser::new(args!["program", "--status-line="])
+                .parse()
+                .unwrap_err()
+                .message,
+            format!(
+                "{}\n\n\"--status-line\" needs a value. Empty string cannot be processed.",
+                HELP
+            ),
+        );
+    }
+
     #[test]
     fn parser_with_starting_point_disallow_option_like_value() {
         assert_eq!(
@@ -482,6 +612,7 @@ mod tests {
                 help: false,
                 version: false,
                 starting_point: String::from("."),
+                status_line: StatusLine::Absolute,
                 query: String::from(""),
                 exec,
             }
