@@ -1,4 +1,3 @@
-// TODO: This file requires refactoring, but first I want to make sure the behavior is expected through testing.
 use std::ffi::{CString, OsString};
 use std::io::{self, Stderr, Stdout, Write};
 use std::os::raw::c_char;
@@ -290,8 +289,10 @@ fn find_paths(starting_point: &StartingPoint, query: &str, limit: u16) -> Result
 
     for path in Finder::new(starting_point, query)? {
         // TODO: Shouldn't we stop iteration when some paths returns Err?
-        let path = path?;
-        paths.push(path);
+        match path {
+            Ok(path) => paths.push(path),
+            Err(_) => (), // TODO: Output failed paths to a log file.
+        }
     }
 
     paths.sort();
@@ -300,6 +301,8 @@ fn find_paths(starting_point: &StartingPoint, query: &str, limit: u16) -> Result
 
 /// Invoke the specified command with the selected path.
 fn invoke(exec: &str, path: &str) -> Result<()> {
+    // TODO: This function is not tested because execvp(3) replaces the current process with a new process, which means tests will stop.
+
     let mut cstrings: Vec<CString> = Vec::with_capacity(10); // TODO: Why is it 10?
     for arg in exec.split_whitespace() {
         cstrings.push(CString::new(arg)?);
