@@ -1,7 +1,7 @@
 pub use args::HELP;
 pub use cli::{entrypoint, safe_exit};
 pub use error::{Error, ErrorKind, Result};
-pub use terminal::{DefaultTerminal, Terminal};
+pub use terminal::{DefaultTerminal, DefaultTerminalEvent, Terminal, TerminalEvent};
 
 mod args;
 mod cli;
