@@ -1,6 +1,6 @@
 use std::ffi::OsString;
 
-use helper::MockTerminal;
+use helper::{MockTerminal, MockTerminalEvent};
 use thwack::entrypoint;
 
 mod helper;
@@ -13,7 +13,7 @@ fn version() -> String {
 fn show_version() {
     let args = args!["thwack", "--version"];
     let mut buffer = buf!();
-    let result = entrypoint(args, &mut buffer, MockTerminal);
+    let result = entrypoint(args, &mut buffer, MockTerminal, MockTerminalEvent::new());
     assert!(result.is_ok());
     assert_eq!(buffer, buf!(version()));
 }
@@ -22,7 +22,7 @@ fn show_version() {
 fn show_version_with_query() {
     let args = args!["thwack", "--version", "--", "query"];
     let mut buffer = buf!();
-    let result = entrypoint(args, &mut buffer, MockTerminal);
+    let result = entrypoint(args, &mut buffer, MockTerminal, MockTerminalEvent::new());
     assert!(result.is_ok());
     assert_eq!(buffer, buf!(version()));
 }
@@ -31,7 +31,7 @@ fn show_version_with_query() {
 fn show_version_with_starting_point() {
     let args = args!["thwack", "--version", "--starting-point=/tmp"];
     let mut buffer = buf!();
-    let result = entrypoint(args, &mut buffer, MockTerminal);
+    let result = entrypoint(args, &mut buffer, MockTerminal, MockTerminalEvent::new());
     assert!(result.is_ok());
     assert_eq!(buffer, buf!(version()));
 }
